#[non_exhaustive]pub struct SPI2<'a> { /* private fields */ }Expand description
SPI2 peripheral singleton
Implementations
Sourceimpl SPI2<'_>
impl SPI2<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.
Sourcepub fn reborrow(&mut self) -> SPI2<'_>
pub fn reborrow(&mut self) -> SPI2<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.
Sourcepub fn bind_peri_interrupt(&self, handler: InterruptHandler)
Available on crate feature unstable only.
pub fn bind_peri_interrupt(&self, handler: InterruptHandler)
unstable only.Binds an interrupt handler to the corresponding interrupt for this peripheral, and enables the interrupt.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn enable_peri_interrupt(&self, priority: Priority)
pub fn enable_peri_interrupt(&self, priority: Priority)
Enables the SPI2 peripheral interrupt on the given priority level.
Note that a suitable interrupt handler needs to be set up before the first interrupt
is triggered, otherwise the default handler will panic.
To set up an interrupt handler, use Self::bind_peri_interrupt or create a function that has the same (non-mangled) name as the interrupt you want to handle.
Examples
use esp_hal::interrupt::Priority;
#[unsafe(no_mangle)]
unsafe extern "C" fn SPI2() {
// do something
}
peripherals.SPI2.enable_peri_interrupt(Priority::Priority1);
peripherals.SPI2.disable_peri_interrupt_on_all_cores();Sourcepub fn disable_peri_interrupt(&self)
Available on crate feature unstable only.
pub fn disable_peri_interrupt(&self)
unstable only.Disables the SPI2 peripheral interrupt handler on the current CPU core.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn disable_peri_interrupt_on_all_cores(&self)
pub fn disable_peri_interrupt_on_all_cores(&self)
Disables the SPI2 peripheral interrupt handler on all cores.
Sourceimpl SPI2<'_>
impl SPI2<'_>
Sourcepub const PTR: *const <SPI2 as Deref>::Target = pac::SPI2::PTR
Available on crate feature unstable only.
pub const PTR: *const <SPI2 as Deref>::Target = pac::SPI2::PTR
unstable only.Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <SPI2 as Deref>::Target
Available on crate feature unstable only.
pub const fn ptr() -> *const <SPI2 as Deref>::Target
unstable only.Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn regs<'a>() -> &'a <SPI2 as Deref>::Target
Available on crate feature unstable only.
pub const fn regs<'a>() -> &'a <SPI2 as Deref>::Target
unstable only.Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn register_block(&self) -> &<SPI2 as Deref>::Target
Available on crate feature unstable only.
pub fn register_block(&self) -> &<SPI2 as Deref>::Target
unstable only.Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.